mcipc - A Minecraft inter-process communication library
=======================================================

`mcipc` is a Python 3 library, which provides clients to interact with Minecraft servers.
It therefor implements the `RCON <http://wiki.vg/RCON>`_ and `Query <http://wiki.vg/Query>`_ protocols.
There is also work on the Minecraft server protocol in progress, but you should not rely on that code.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   usage
   query
   rcon
   scripts
   modules
   bugs
   license


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
